@@ -1,9 +1,11 @@
+use core::arch::asm;
+
 /// Read the RIP register (instruction pointer).
 #[inline(always)]
 pub fn rip() -> u64 {
     let rip: u64;
     unsafe {
-        llvm_asm!("leaq 0(%rip), $0" : "=r" (rip) ::);
+        asm!("leaq 0(%rip), {0}", out(reg) rip, options(att_syntax));
     }
     rip
 }
@@ -13,7 +15,7 @@ pub fn rip() -> u64 {
 pub fn rsp() -> u64 {
     let rsp: u64;
     unsafe {
-        llvm_asm!("mov %rsp, $0" : "=r" (rsp) ::);
+        asm!("mov %rsp, {0}", out(reg) rsp, options(att_syntax));
     }
     rsp
 }
@@ -23,7 +25,7 @@ pub fn rsp() -> u64 {
 pub fn rbp() -> u64 {
     let rbp: u64;
     unsafe {
-        llvm_asm!("mov %rbp, $0" : "=r" (rbp) ::);
+        asm!("mov %rbp, {0}", out(reg) rbp, options(att_syntax));
     }
     rbp
 }
